@@ -273,4 +273,26 @@ sub DELETE_view_list {
 }
 
 1;
+__END__
+
+=head1 NAME
+
+OpenResty::Handler::View - The view handler for OpenResty
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+This OpenResty handler class implements the View API, i.e., the C</=/view/*> stuff.
+
+=head1 METHODS
+
+=head1 AUTHORS
+
+Laser Henry (laser) C<< <laserhenry at gmail dot com> >>,
+Agent Zhang (agentzh) C<< <agentzh@gmail.com >>
+
+=head1 SEE ALSO
+
+L<OpenResty::Handler::Model>, L<OpenResty::Handler::Role>, L<OpenResty::Handler::Action>, L<OpenResty::Handler::Feed>, L<OpenResty::Handler::Version>, L<OpenResty::Handler::Captcha>, L<OpenResty::Handler::Login>, L<OpenResty>.
 
